/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Gnu General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Gnu General Public License for more details.
 *
 * You should have received a copy of the Gnu General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nest;

import anthill.*;
import anthill.util.*;

/**
 *  The <CODE>RequestSet</CODE> interface represents a data structure
 *  containing associations between ant identifiers and listeners 
 *  interested in the responses returned by those ants. 
 *  <p>
 *  <CODE>RequestSet</CODE> is one of the components of a nest; the
 *  other are <CODE>Manager</CODE>), <CODE>Trail</CODE>, 
 *  <CODE>Storage</CODE> and <CODE>Gate</CODE>.
 * 
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface RequestSet
extends Clearable
{

  /**
   *  Adds an association between ant identifier and the listener 
   *  interested in the responses returned by this ant.
   *
   *  @param aid the ant identifier 
   *  @param listener the listener which will be notified when
   *    a response is available
   */
  public void add(AntId aid, ResponseListener listener);
  
 
  /**
   *  Returns the specified resources to the listener associated
   *  to the given ant identifier.
   * 
   *  @param aid        the ant identifier
   *  @param resources  the resources found.
   */
  public void returnResources(AntId aid, Resource[] resources);
  
} // END RequestSet
